# Laravel Installations

## Install

### Add Myriad Repository

The client is distributed internally with Satis. First add the repository to `composer.json`:

```json
  "repositories": [
    {
      "type": "composer",
      "url": "https://satis.myriadmobile.com"
    }
  ]
```

### Require the Dependency

Require this package with composer using the following command:

```bash
composer require myriad/laravel-installations
```

### Install Service Provider

After updating composer, add the service provider to the `providers` array in `config/app.php`:

```php
Myriad\Installations\InstallationsServiceProvider::class,
```

Additionally, the default configuration requires some validators from the myriad/laravel-validators package.
As such, you must also include the validator service provider:

```php
Myriad\Validators\ValidatorServiceProvider::class,
```

### Publish Migrations

Rather than creating your own migrations table, you can publish the one from the installations package:

```bash
php artisan vendor:publish --provider="Myriad\Installations\InstallationsServiceProvider" --tag="migrations"
```

### Configuration

The installations package is designed to work out of the box with out an configuration. Should you need to edit the configuration, 
publish the installations config file to the `config` directory:

```bash
php artisan vendor:publish --provider="Myriad\Installations\InstallationsServiceProvider" --tag="config"
```

### Middleware

The installations package ships with a middleware instance that collects and validates installation data from every request:

```php
Myriad\Installations\Middleware\VerifyInstallation::class
```

## Usage

Get the installation for the current request:

```php
$installation = app(Myriad\Installations\InstallationManager::class);
$installation->getInstallation();
```

Look up an installation by its uuid:

```php
$installation = app(Myriad\Installations\InstallationManager::class);
$installation->findInstallationByUUID($uuid);
```

Look up an installation by its auto-incrementing id:

```php
$installation = app(Myriad\Installations\InstallationManager::class);
$installation->findInstallationById($id);
```

## Customization

### Controller/Responses

Create a new controller that extends `Myriad\Installations\Controllers\InstallationsController` and override the methods you see fit.
Then, publish the configuration file and edit the routes to point to your new controller. Optionally, you can manually register the routes in your
`app/Http/routes.php` file and disable routing in your `config/installations.php` file.

### Validation
