<?php

return [

  /*
  |--------------------------------------------------------------------------
  | Routes
  |--------------------------------------------------------------------------
  |
  | This value determines all aspects of routing for the Installations
  | package. Set "enabled" to false if you are defining the routes manually
  | in your routes.php file.
  |
  | The "api.group" value allows passing additional parameters to
  | Route::group()
  |
  | The "api.show" and "api.store" values allow passing additional parameters
  | to the store and show route definitions.
  |
  */

  'routes' => [
    'enabled' => true,
    'api' => [
      'group' => ['prefix' => 'api/v1/installations'],
      'show' => ['uses' => 'Myriad\Installations\Controllers\InstallationsController@show', 'as' => 'installations.show'],
      'store' => ['uses' => 'Myriad\Installations\Controllers\InstallationsController@store', 'as' => 'installations.store'],
    ],
  ],

  /*
  |--------------------------------------------------------------------------
  | Request Map
  |--------------------------------------------------------------------------
  |
  | The request map allows you to specify the header and query parameters
  | that are searched in each request to find installation data.
  |
  */

  'request_map' => [
    'app_installation_id' => [
      'header' => env('INSTALLATIONS_APP_INSTALLATION_ID_HEADER', 'App-Installation-Id'),
      'query' => env('INSTALLATIONS_APP_INSTALLATION_ID_QUERY', 'installation_id'),
    ],
    'app_name' => [
      'header' => env('INSTALLATIONS_APP_NAME_HEADER', 'App-Name'),
      'query' => env('INSTALLATIONS_APP_NAME_QUERY', 'installation_app_name'),
    ],
    'app_version' => [
      'header' => env('INSTALLATIONS_APP_VERSION_HEADER', 'App-Version'),
      'query' => env('INSTALLATIONS_APP_VERSION_QUERY', 'installation_app_version'),
    ],
    'platform_name' => [
      'header' => env('INSTALLATIONS_PLATFORM_NAME_HEADER', 'Platform-Name'),
      'query' => env('INSTALLATIONS_PLATFORM_NAME_QUERY', 'installation_platform_name'),
    ],
    'platform_version' => [
      'header' => env('INSTALLATIONS_PLATFORM_VERSION_HEADER', 'Platform-Version'),
      'query' => env('INSTALLATIONS_PLATFORM_VERSION_QUERY', 'installation_platform_version'),
    ],
  ],

  /*
  |--------------------------------------------------------------------------
  | Validator
  |--------------------------------------------------------------------------
  |
  | This value allows you to change the default installation validator. You
  | may change it here or optionally bind a class that implements
  | "IInstallationValidationProvider" to "installations.validator"
  |
  */

  'validator' => \Myriad\Installations\Validation\InstallationValidationProvider::class,

  /*
  |--------------------------------------------------------------------------
  | Table Name
  |--------------------------------------------------------------------------
  |
  | This value determines the table to store installations in.
  |
  */

  'table_name' => env('INSTALLATIONS_TABLE_NAME', 'installations'),

];