<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

/**
 * Class CreateInstallationsTable creates the installations table in the database.
 */
class CreateInstallationsTable extends Migration {

  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {
    Schema::create($this->getTableName(), function(Blueprint $table) {
      $table->increments('id');
      $table->uuid('uuid')->unique();
      $table->string('app_name', 64)->nullable();
      $table->string('app_version', 64)->nullable();
      $table->string('platform_name', 16)->nullable();
      $table->string('platform_version', 32)->nullable();
      $table->string('locale', 16)->nullable();
      $table->string('timezone', 64)->nullable();
      $table->string('push_type', 16)->nullable();
      $table->string('push_id', 255)->nullable();
      $table->text('user_agent')->nullable();
      $table->text('custom')->nullable();
      $table->timestamps();
      $table->softDeletes();
    });
  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::drop($this->getTableName());
  }

  /**
   * Get the table name from the config file
   *
   * @return string the table name
   */
  private function getTableName() {
    return config('installations.table_name', 'installations');
  }

}
