<?php namespace Myriad\Installations;

use Illuminate\Contracts\Foundation\Application;
use Illuminate\Support\ServiceProvider;

/**
 * Class InstallationsServiceProvider makes Installations available to Laravel applications.
 *
 * @package Myriad\Installations
 */
class InstallationsServiceProvider extends ServiceProvider {

  /**
   * Perform post-registration booting of services.
   *
   * @return void
   */
  public function boot() {
    // include routes
    if (!$this->app->routesAreCached() && config('installations.routes.enabled')) {
      require __DIR__ . '/routes.php';
    }

    // publish config and migrations
    $this->publishes([__DIR__ . '/../database/migrations/' => database_path('migrations') ], 'migrations');
    $this->publishes([__DIR__ . '/../config/installations.php' => config_path('installations.php')], 'config');
  }

  /**
   * Register the service provider.
   *
   * @return void
   */
  public function register() {
    $this->mergeConfigFrom(__DIR__ . '/../config/installations.php', 'installations');

    // register the validator
    $this->app->singleton('installations.validator', config('installations.validator', \Myriad\Installations\Validation\InstallationValidationProvider::class));
    $this->app->alias('installations.validator', \Myriad\Installations\Validation\IInstallationValidationProvider::class);

    // register the manager
    $this->app->singleton('installations.manager', function(Application $app) {
      return new InstallationManager($app->make('request'), $app->make('config'), $app->make('installations.validator'));
    });
    $this->app->alias('installations.manager', \Myriad\Installations\InstallationManager::class);
  }

  /**
   * Get the services provided by the provider.
   *
   * @return array
   */
  public function provides() {
    return [
      'installations.manager',
      \Myriad\Installations\InstallationManager::class,
      'installations.validator',
      \Myriad\Installations\Validation\InstallationValidationProvider::class,
      \Myriad\Installations\Validation\IInstallationValidationProvider::class
    ];
  }

}