<?php namespace Myriad\Installations\Validation;

use Myriad\Installations\Exceptions\InstallationValidationException;

/**
 * Interface IInstallationValidationProvider defines the methods expected by an object capable of validating
 * installations.
 *
 * @package Myriad\Installations\Validation
 */
interface IInstallationValidationProvider {

  /**
   * Get the rules used to validate an installation.
   *
   * @param array $data The data to return rules for.
   * @return array
   */
  public function getRules($data = []);

  /**
   * Get custom messages.
   *
   * @param array $data The data to return messages for.
   * @return array
   */
  public function getMessages($data = []);

  /**
   * Get a validator for the given data.
   *
   * @param array $data The data to get a validator for.
   * @return \Illuminate\Contracts\Validation\Validator
   */
  public function getValidator($data);

  /**
   * Validates a UUID.
   *
   * @param string $uuid The UUID to validate.
   * @return true
   * @throws InstallationValidationException
   */
  public function validateUUID($uuid);

  /**
   * Normalizes a UUID to string.
   *
   * @param string $uuid The UUID to validate.
   * @return string
   */
  public function normalizeUUID($uuid);

}